
//_______________________________________________________________________________________________________________
/****************************************************************************************************************/
/*                                                                                                              */
/*                     B I N S E M                                                                              */
/*                                                                                                              */
/****************************************************************************************************************/

#ifndef _OS_SETBIT_BINSEM
#define _OS_SETBIT_BINSEM(binsem)   {OS_BSems[(binsem) >> _OST_INT_SHIFT] |= (1 << ((binsem) & _OST_INT_MASK));}
#endif
    
#ifndef _OS_CLRBIT_BINSEM
#define _OS_CLRBIT_BINSEM(binsem)   {OS_BSems[(binsem) >> _OST_INT_SHIFT] &= ~(1 << ((binsem) & _OST_INT_MASK));}
#endif

#ifndef _OS_TGLBIT_BINSEM
#define _OS_TGLBIT_BINSEM(binsem)   {OS_BSems[(binsem) >> _OST_INT_SHIFT] ^= (1 << ((binsem) & _OST_INT_MASK));}
#endif

    

//------------------------------------------------------------------------------
//  
#define OS_SetBSem(binsem)        _OS_SETBIT_BINSEM(binsem)
#define OS_SignalBSem(binsem)     OS_SetBSem(binsem)

//------------------------------------------------------------------------------
//  
#define OS_ResetBSem(binsem)     _OS_CLRBIT_BINSEM(binsem)

//------------------------------------------------------------------------------
// ,   
#define OS_CheckBSem(binsem)     (OS_BSems[(binsem) >> _OST_INT_SHIFT] & (1 << ((binsem) & _OST_INT_MASK)))

//------------------------------------------------------------------------------
//   
#define OS_SwitchBSem(binsem)    _OS_TGLBIT_BINSEM(binsem)
    
//------------------------------------------------------------------------------
//   

#define OS_WaitBSem(binsem)                                           \
    {                                                                 \
        _OS_WAIT_EVENT(OS_CheckBSem(binsem));                         \
        OS_ResetBSem(binsem);                                         \
    }

//-------------------------------------------------------------------------------
//    

#define OS_WaitBSemTimeout(binsem, timeout)                           \
    {                                                                 \
        _OS_WAIT_EVENT_TIMEOUT(OS_CheckBSem(binsem), timeout);        \
        OS_ResetBSem(binsem);                                         \
    }


//-------------------------------------------------------------------------------
//        
#define OS_SetWaitBSem(set_binsem, wait_binsem)                       \
    {                                                                 \
        OS_SetBSem(set_binsem);                                       \
        OS_ResetBSem(wait_binsem);                                    \
        OS_WaitBSem(wait_binsem);                                     \
    }


//-------------------------------------------------------------------------------
//          
#define OS_SetWaitBSemTimeout(set_binsem, wait_binsem, timeout)           \
    {                                                                     \
        OS_SetBSem(set_binsem);                                           \
        OS_ResetBSem(wait_binsem);                                        \
        OS_WaitBSemTimeout(wait_binsem);                                  \
    }



    
